summaryrefslogtreecommitdiffstats
path: root/lib/kotext/TimeFormatWidget.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kotext/TimeFormatWidget.cpp
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kotext/TimeFormatWidget.cpp')
-rw-r--r--lib/kotext/TimeFormatWidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/kotext/TimeFormatWidget.cpp b/lib/kotext/TimeFormatWidget.cpp
index 34fd7cb2..06603969 100644
--- a/lib/kotext/TimeFormatWidget.cpp
+++ b/lib/kotext/TimeFormatWidget.cpp
@@ -15,11 +15,11 @@
#include <KoVariable.h>
/*
* Constructs a TimeFormatWidget which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/
-TimeFormatWidget::TimeFormatWidget( TQWidget* tqparent, const char* name, WFlags fl )
- : TimeDateFormatWidgetPrototype( tqparent, name, fl )
+TimeFormatWidget::TimeFormatWidget( TQWidget* parent, const char* name, WFlags fl )
+ : TimeDateFormatWidgetPrototype( parent, name, fl )
{
setCaption( i18n( "TimeFormat", "This Dialog Allows You to Set the Format of the Time Variable" ) );
@@ -15,11 +15,11 @@
#include <KoVariable.h>
/*
- * Constructs a TimeFormatWidget which is a child of 'tqparent', with the
+ * Constructs a TimeFormatWidget which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/